@@ -56,13 +56,21 @@ def _end_call(page_ident, page_type, skicall):
 class SkipoleProject(object):
     """The SkipoleProject - an instance being a callable WSGI application"""
 
-    def __init__(self, project, projectfiles, proj_data={}, start_call=None, submit_data=None, end_call=None, url="/"):
+    def __init__(self, project, projectfiles, proj_data={}, start_call=None, submit_data=None, end_call=None, url="/", proj_ident=None):
         """Loads the project from JSON files and records the user functions"""
         if _AN.search(project):
             raise ServerError(message="Error: Invalid project name, alphanumeric only")
         if '_' in project:
             raise ServerError(message="Error: Invalid project name, alphanumeric only (no underscore).")
-        self._proj_ident = project
+        if proj_ident is None:
+            self._proj_ident = project
+        else:
+            if _AN.search(proj_ident):
+                raise ServerError(message="Error: Invalid proj_ident, alphanumeric only")
+            if '_' in project:
+                raise ServerError(message="Error: Invalid proj_ident, alphanumeric only (no underscore).")
+            self._proj_ident = proj_ident
+        self.proj_name = project
         self.projectfiles = projectfiles
         self.proj_data = proj_data
         if start_call is None:
@@ -111,7 +119,10 @@ class SkipoleProject(object):
         self.identitems = {}
 
         # Create an instance of the AccessTextBlocks class for this project
-        self.textblocks = textblocks.AccessTextBlocks(self._proj_ident, projectfiles, skiboot.default_language())
+        # self.proj_name is used as the location of the textblocks json file is
+        # found at os.path.join(projectfiles, project, "data", "textblocks_json")
+        # where project is the project name, not the proj_ident
+        self.textblocks = textblocks.AccessTextBlocks(self.proj_name, projectfiles, skiboot.default_language())
 
         # maintain a cach dictionary of paths against idents {path:ident}
         self._paths = {}
@@ -505,7 +516,7 @@ class SkipoleProject(object):
             # create the SkiCall object
             skicall = SkiCall(environ = environ,
                               path = path,
-                              project = self._proj_ident,
+                              proj_ident = self._proj_ident,
                               rootproject = self.rootproject,
                               caller_ident = tuple_caller_ident,
                               received_cookies = received_cookies,
@@ -673,14 +684,14 @@ class SkipoleProject(object):
 
         # call the user function end_call
         try:
-            skicall.project = self._proj_ident
+            skicall.proj_ident = self._proj_ident
             skicall.proj_data = self.proj_data
             skicall.rootproject = self.rootproject
             try:
                 session_string = self.end_call(page.ident.to_tuple(), page.page_type, skicall)
                 if session_string:
                     # set cookie in target_page
-                    page.session_cookie = "Set-Cookie", "%s=%s; Path=%s" % (skicall.project, session_string, skiboot.root_project().url)
+                    page.session_cookie = "Set-Cookie", "%s=%s; Path=%s" % (skicall.proj_ident, session_string, skiboot.root_project().url)
             except FailPage as e:
                 page.show_error([e.errormessage])
             finally:
@@ -728,7 +739,7 @@ class SkipoleProject(object):
 
     def load_from_json(self):
         "Loads project with data saved in project.json file"
-        projectdict = read_json.create_project(self._proj_ident, self.projectfiles)
+        projectdict = read_json.create_project(self._proj_ident, self.projectfiles, self.proj_name)
         self.default_language = projectdict['default_language']
         self.brief = projectdict['brief']
         self.version = projectdict['version']
@@ -1120,11 +1131,11 @@ class SkipoleProject(object):
         if isinstance(ident, int):
             ident = skiboot.Ident(self._proj_ident, ident)
         elif ident.proj != self._proj_ident:
-            return None
+            return
         if ident.num == 0:
             return self.root
         if ident not in self.identitems:
-            return None
+            return
         return self.identitems[ident]
 
 
@@ -1165,6 +1176,8 @@ class SkipoleProject(object):
             if len(target.split(',')) == 2:
                 # item points to a subproject label
                 item = target
+            else:
+                raise ServerError(message="Sorry, label target not recognised")
         else:
             item = skiboot.make_ident(target, self._proj_ident)
             if not item:
@@ -1192,7 +1205,7 @@ class SkipoleProject(object):
 
 
     def labels(self):
-        "Returns the special pages dictionary as a dictionary of labels with url's and tuples"
+        "Returns the special pages dictionary as a dictionary of labels with strings and and idents as tuples"
         labels_dict = {}
         for key, val in self.special_pages.items():
             if isinstance(val, str):
@@ -1203,17 +1216,79 @@ class SkipoleProject(object):
 
 
     def label_value(self, key):
-        "Returns the url or tuple associated with the label"
+        "Returns the special_pages string or ident as tuple associated with the label"
         val = self.special_pages.get(key)
         if val is None:
             return
-        labels_dict = {}
         if isinstance(val, str):
             return val
         else:
             return val.to_tuple()
 
 
+    def resolve_label(self, label, depth=4):
+        """Given a page label, resolves the label to ident tuple
+           Follows subproject labels to the given depth, limited to avoid circular references
+           Returns either the tuple, or URL string, or None if unsuccessful"""
+        depth = depth-1
+        if depth < 0:
+            return
+        value = self.label_value(label)
+        if value is None:
+            return
+        if isinstance(value, tuple):
+            # its an ident tuple
+            return value
+        # so value is a string, either URL, or something like "subproject, label"
+        # or "subproject, integer" which should be returned as a tuple
+        if "/" in value:
+            # Its a url
+            return value
+        if ',' not in value:
+            # not sure what this is, but in case of future possible strings, return it
+            return value
+        vallist = value.split(',')
+        if len(vallist) != 2:
+            # invalid
+            return
+        if vallist[1].isdigit():
+            # Its "subproject, integer"
+            try:
+                return (vallist[0], int(vallist[1]))
+            except:
+                return
+        # Its "subproject, label"
+        subproj = skiboot.getproject(vallist[0])
+        if subproj is None:
+            return
+        return subproj.resolve_label(vallist[1], depth)
+
+
+    def label_to_url(self, label, depth=4):
+        """Given a page label, resolves the label to url string
+           Follows subproject labels to the given depth, limited to avoid circular references
+           Returns either the URL string, or None if unsuccessful"""
+
+        value = self.resolve_label(label, depth)
+        if value is None:
+            return
+        if isinstance(value, str):
+            # a url
+            return value
+        # value is "proj_id, integer"
+        proj = skiboot.getproject(value[0])
+        if proj is None:
+            return
+        # Get the page or folder of the proj
+        item = proj.get_item(value[1])
+        if item is None:
+            return
+        url = item.url
+        if not url:
+            return
+        return url
+
+
     def _redirect_to_url(self, url, environ, call_data, page_data, lang):
         "Return status, headers, page.data() of the redirector page, with fields set to url"
         if '/' not in url:
@@ -1390,11 +1465,11 @@ class SkiCall(object):
     """SkiCall is the class of the skicall object which is created for each incoming
        call and is passed as an argument to the user functions"""
 
-    def __init__(self, environ, path, project, rootproject, caller_ident, received_cookies, ident_data, lang, proj_data):
+    def __init__(self, environ, path, proj_ident, rootproject, caller_ident, received_cookies, ident_data, lang, proj_data):
 
         self.environ = environ
         self.path = path
-        self.project = project
+        self.proj_ident = proj_ident
         self.rootproject = rootproject
         self.caller_ident = caller_ident
         self.received_cookies = received_cookies
@@ -1403,14 +1478,17 @@ class SkiCall(object):
         self._lang_cookie = None
         self.proj_data = proj_data
 
-        self._projectfiles = skiboot.projectfiles(project)
-
         self.ident_list = []
         self.submit_list = []
         self.submit_dict = {'error_dict':{}}
         self.call_data = {}
         self.page_data = {}
 
+    @property
+    def project(self):
+        return skiboot.project_name(self.proj_ident)
+
+
     def update(self, itemdata):
         "Updates page_data from a PageData, SectionData or Dictionary"
         if isinstance(itemdata, PageData):
@@ -1454,7 +1532,7 @@ class SkiCall(object):
     @property
     def projectfiles(self):
         "Returns the projectfiles string"
-        return self._projectfiles
+        return skiboot.projectfiles(self.proj_ident)
 
     @property
     def lang(self):
@@ -1476,27 +1554,27 @@ class SkiCall(object):
     @property
     def accesstextblocks(self):
         "Returns the project instance of the AccessTextBlocks class"
-        this_project = skiboot.getproject(proj_ident=self.project)
+        this_project = skiboot.getproject(self.proj_ident)
         return this_project.textblocks
 
-    def textblock(self, textref, project=None):
+    def textblock(self, textref, proj_ident=None):
         """This method returns the textblock text, given a textblock reference string,
-           If project is not given assumes this project, if given, project must exist as either the root,
+           If proj_ident is not given assumes this project, if given, project must exist as either the root,
            or a sub project of the root.
            If no textblock is found, returns None."""
-        if project is None:
-            project = self.project
-        proj = skiboot.getproject(project)
+        if proj_ident is None:
+            proj_ident = self.proj_ident
+        proj = skiboot.getproject(proj_ident)
         if proj is None:
             return
         return proj.textblocks.get_text(textref, self.lang)
 
 
-    def ident_from_path(self, path, project=None):
-        "Returns tuple of projectname, ident number, of the page or folder given by the path, or None if not found"
-        if project is None:
-            project = self.project
-        proj = skiboot.getproject(project)
+    def ident_from_path(self, path, proj_ident=None):
+        "Returns tuple of proj_ident, ident number, of the page or folder given by the path, or None if not found"
+        if proj_ident is None:
+            proj_ident = self.proj_ident
+        proj = skiboot.getproject(proj_ident)
         if proj is None:
             return
         ident = proj.root.ident_from_path(path)
@@ -1504,28 +1582,39 @@ class SkiCall(object):
             return ident.to_tuple()
 
 
-    def label_value(self, label, project=None):
-        """Given a label, returns the associated ident or URL
-           If project is not given assumes this project, if given, project must exist as either the root,
+    def label_value(self, label, proj_ident=None):
+        """Given a label, returns the associated URL, or ident as a tuple
+           If proj_ident is not given assumes this project, if given, project must exist as either the root,
            or a sub project of the root.
            If no label is found, returns None."""
-        if project is None:
-            project = self.project
-        proj = skiboot.getproject(project)
+        if proj_ident is None:
+            proj_ident = self.proj_ident
+        proj = skiboot.getproject(proj_ident)
         if proj is None:
             return
-        return proj.label_value(label)
+        value = proj.label_value(label)
+        if value is None:
+            return
+        if isinstance(value, str):
+            if "/" in value:
+                # a url
+                return value
+            if (',' in value ) and not (value.split(',')[1].isdigit()):
+                if len(value.split(',')) == 2:
+                    # item points to a subproject label
+                    return tuple(value.split(','))
+        return value
 
 
     def projectpaths(self):
-        """Returns a dictionary of project name : project path
+        """Returns a dictionary of project idents : project path
 
-           This method returns a dictionary of project names as keys with the project paths as values."""
+           This method returns a dictionary of project idents as keys with the project paths as values."""
         return skiboot.projectpaths()
 
     def makepath(self, *foldernames):
         "Returns a url path string starting with the projects path, with the given foldernames joined"
-        projectpath = self.projectpaths()[self.project]
+        projectpath = self.projectpaths()[self.proj_ident]
         if not foldernames:
             return projectpath
         folderpath =  "/".join(foldernames)
@@ -1556,7 +1645,7 @@ class SkiCall(object):
             return
         if not urlfolder.startswith("/"):
             # relative path, pre-pend the project url
-            projectpath = self.projectpaths()[self.project]
+            projectpath = self.projectpaths()[self.proj_ident]
             if projectpath.endswith("/"):
                 urlfolder = projectpath + urlfolder
             else:
