@@ -159,6 +159,37 @@ For a single given key in call data, if present, that key:value will be deleted
         return self.get_target_page(proj_ident)
 
 
+class AddCallDataItem(Respond):
+    """
+Adds a single given key and value in call data.
+"""
+
+    # This indicates a target page ident is required
+    target_ident_required = True
+
+
+    # Options for the fields argument
+    field_options = {'fields': True,                  # If False, no fields are expected
+                     'widgfields':False,               # If True, fields are widgfields, if False, can be other constants
+                     'widgfield_values':False,        # If True the field values are widgfields
+                     'fields_optional': False,        # if fields is True, then False here means fields must be supplied
+                     'field_values': True,            # if True, field values are used
+                     'field_keys': False,             # if field_values is True, and this field_keys is True, the values supplied are dictionary keys
+                     'empty_values_allowed':True,     # If True, '' is a valid value, if False, some data must be provided
+                     'single_field': True}            # Only a single field is accepted
+
+
+    def _respond(self, skicall, form_data, caller_page, ident_list, proj_ident, rawformdata):
+        "Adds a call_data item with the given field key and value"
+        call_data = skicall.call_data
+
+        for field, val in self.fields.items():
+            skicall.call_data[field] = val
+            # there should only be one field
+            break
+        return self.get_target_page(proj_ident)
+
+
 class NoOperation(Respond):
     """
 Goes to Target page, can be used as a temporary place holder
