@@ -203,6 +203,7 @@ class ParentPart(object):
         # ident_string normally starts project_pageident_head-0-... etc
         return self.ident_string.split('_')[0]
 
+
     def insert_id(self, id_string=''):
         """Adds the id_string to the part attributes. If no id_string given
            but the part has a name, sets the id to the part name, otherwise
@@ -331,15 +332,15 @@ class ParentPart(object):
         "If valstring starts with a  label in the form {label}, substitute url here"
         if valstring[0] != '{':
             return valstring
-        proj_ident = self.proj_ident
-        if not proj_ident:
+        if not self.proj_ident:
             return valstring
         end = valstring.find('}')
         if end == -1:
             return valstring
         label = valstring[1:end]
         if label:
-            url = skiboot.get_url(label, proj_ident)
+            proj = skiboot.getproject(self.proj_ident)
+            url = proj.label_to_url(label)
             if url:
                 return quote(url, safe='/:?&=@')+valstring[end+1:]
         return valstring
