@@ -28,7 +28,6 @@ _AN = re.compile('[^\w]')
 # text
 # url           - either a url string, label string or ident
 # textblock_ref
-# ident         - the ident of a page or folder
 # element_ident - the string ident of a page element
 # boolean
 # integer
@@ -69,12 +68,6 @@ class ParentFieldArg(object):
                     if val.lower() == 'false':
                         return False
                 return bool(val)
-            elif valtype == 'ident':
-                if val == 0:
-                    return skiboot.make_ident(val)
-                if not val:
-                    return None
-                return skiboot.make_ident(val)
             elif valtype == 'url':
                 if val == 0:
                     sval = '0'
@@ -876,13 +869,20 @@ class Widget(tag.Part):
         else:
             embedded_parts = self.embedded
         if self._error:
-            if isinstance(self._error, TextBlock):
+            if isinstance(self._error, tag.TextBlock):
                 self._error.update(page, ident_list, environ, call_data, lang, self.ident_string, self.placename, embedded_parts)
             return
         # build the widget, set self.wf with field values, this namespace is used in the widget build to access widget field values easily
         self.wf = SimpleNamespace(**{fname:item.value for fname,item in self.fields.items()})
         # set the widget class and style attributes
         self.set_class_style(self.wf.widget_class, self.wf.widget_style)
+        # Set these two into self.jlabels - which in turn sets them into the javascript variable fieldvalues
+        # these are updated by javascript whenever these values are updated by json, making them always available
+        # to the javascript code.
+        if self.wf.widget_class:
+            self.jlabels["widget_class"] = self.wf.widget_class
+        if self.wf.widget_style:
+            self.jlabels["widget_style"] = self.wf.widget_style
         # Insert this widgets id
         self.insert_id()
         # insert further parts according to each widget build
@@ -1596,13 +1596,20 @@ class ClosedWidget(tag.ClosedPart):
         else:
             embedded_parts = self.embedded
         if self._error:
-            if isinstance(self._error, TextBlock):
+            if isinstance(self._error, tag.TextBlock):
                 self._error.update(page, ident_list, environ, call_data, lang, self.ident_string, self.placename, embedded_parts)
             return
         # build the widget, set self.wf with field values, this namespace is used in the widget build to access widget field values easily
         self.wf = SimpleNamespace(**{fname:item.value for fname,item in self.fields.items()})
         # set the widget class and style attributes
         self.set_class_style(self.wf.widget_class, self.wf.widget_style)
+        # Set these two into self.jlabels - which in turn sets them into the javascript variable fieldvalues
+        # these are updated by javascript whenever these values are updated by json, making them always available
+        # to the javascript code.
+        if self.wf.widget_class:
+            self.jlabels["widget_class"] = self.wf.widget_class
+        if self.wf.widget_style:
+            self.jlabels["widget_style"] = self.wf.widget_style
         # Insert this widgets id
         self.insert_id()
         self._build(page, ident_list, environ, call_data, lang)
