@@ -195,9 +195,6 @@ class NavButtons3(Widget):
         get_field1 = self.wf.get_field1
         get_field2 = self.wf.get_field2
 
-        if not button_text:
-            return
-
         link_ident = self.wf.link_ident
         if not link_ident:
             link_ident = 'no_javascript'
@@ -210,6 +207,9 @@ class NavButtons3(Widget):
         if json_ident:
             self.jlabels['jsonurl'] = self.get_url(json_ident)
 
+        if not button_text:
+            return
+
         # for each link - create a link and add it
         for index,txt in enumerate(button_text):
             lnk = tag.Part(tag_name="a", text=txt, attribs={"role":"button"})
@@ -472,7 +472,7 @@ class HeadText(Widget):
      # This class does not display any error messages
     display_errors = False
 
-    arg_descriptions = {'tag':FieldArg("text", 'h1'),
+    arg_descriptions = {'tag':FieldArg("text", 'h1', jsonset=True),
                         'large_text':FieldArg("text", "", jsonset=True)}
 
     def __init__(self, name=None, brief='', **field_args):
