@@ -48,20 +48,21 @@ class ServerTimeStamp(Widget):
 
 
 class PageIdent(Widget):
-    """A widget containing the given ident which is set within the text
-         If no page ident is given, shows ident of the current page"""
+    """A widget displaying the ident of a page label
+       If no page label or span_text are given,
+       shows ident of the current page"""
 
     # This class does not display any error messages
     display_errors = False
 
-    arg_descriptions = {'page_ident':FieldArg("ident", ''),
+    arg_descriptions = {'page_label':FieldArg("text", ''),
                         'span_text':FieldArg("text", "", jsonset=True)
                        }
 
     def __init__(self, name=None, brief='', **field_args):
         """
-        page_ident: The ident of a page or folder, converted to string
-        span_text: if given, overrides the page_ident value
+        page_label: The label of a page or folder
+        span_text: if given, overrides the page ident value
         """
         Widget.__init__(self, name=name, brief=brief, **field_args)
         self.tag_name = "span"
@@ -70,8 +71,23 @@ class PageIdent(Widget):
         "Build the element"
         if self.wf.span_text:
             self[0] = self.wf.span_text
-        elif self.wf.page_ident:
-            self[0] = self.wf.page_ident.to_comma_str()
+        elif self.wf.page_label:
+            proj = skiboot.getproject(self.proj_ident)
+            # its a label string of this project
+            if proj is None:
+                self[0] = f"Unable to resolve the ident of {self.wf.page_label}"
+                return
+            value = proj.resolve_label(self.wf.page_label)
+            # so value is one of the tuple ident, None, or URL
+            if not value:
+                self[0] = f"Unable to resolve the ident of {self.wf.page_label}"
+                return
+            if isinstance(value, str):
+                # a url
+                self[0] = f"Given label points to URL rather than a page ident"
+                return
+            # an ident tuple
+            self[0] = f"{value[0]},{value[1]}"
         else:
             self[0] = page.ident.to_comma_str()
 
@@ -81,7 +97,7 @@ class PageIdent(Widget):
         """Returns a text string to illustrate the widget"""
         return """
 <span>  <!-- with widget id and class widget_class -->
-  <!-- string value of the page_ident, or span_text -->
+  <!-- string value of the page ident, or span_text -->
 </span>
 """
 
@@ -93,13 +109,13 @@ class PageName(Widget):
     # This class does not display any error messages
     display_errors = False
 
-    arg_descriptions = {'page_ident':FieldArg("ident", ''),
+    arg_descriptions = {'page_ident':FieldArg("text", ''),
                         'span_text':FieldArg("text", "", jsonset=True)
                        }
 
     def __init__(self, name=None, brief='', **field_args):
         """
-        page_ident: The ident of a page or folder
+        page_ident: The label or ident of a page or folder
         span_text: if given, overrides the page name value
         """
         Widget.__init__(self, name=name, brief=brief, **field_args)
@@ -110,7 +126,59 @@ class PageName(Widget):
         if self.wf.span_text:
             self[0] = self.wf.span_text
         elif self.wf.page_ident:
-            requested_page = skiboot.get_item(self.wf.page_ident)
+            proj = skiboot.getproject(self.proj_ident)
+            if "/" in self.wf.page_ident:
+                # its a URL
+                self[0] = f"Unable to resolve {self.wf.page_ident}"
+                return
+
+            if self.wf.page_ident.isdigit():
+                # Its "integer"
+                try:
+                    value = (self.proj_ident, int(self.wf.page_ident))
+                except:
+                    self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                    return
+            elif ',' in self.wf.page_ident:
+                # Its a string such as "proj_ident,number"
+                vallist = self.wf.page_ident.split(',')
+                if len(vallist) != 2:
+                    self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                    return
+                lblproj = vallist[0].strip(" ()[]\"\'")
+                lblval = vallist[1].strip(" ()[]\"\'")
+                if lblval.isdigit():
+                    # Its "subproject, integer"
+                    try:
+                        value = (lblproj, int(lblval))
+                    except:
+                        self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                        return
+                else:
+                    # Its "subproject, label"
+                    subproj = skiboot.getproject(lblproj)
+                    if subproj is None:
+                        self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                        return
+                    value = subproj.resolve_label(lblval)
+            else:
+                 # its a label string of this project
+                if proj is None:
+                    self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                    return
+                value = proj.resolve_label(self.wf.page_ident)
+
+            # so value is one of the tuple ident, None, or URL
+            if not value:
+                self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                return
+            if isinstance(value, str):
+                # a url
+                self[0] = f"Given label points to URL rather than an ident"
+                return
+            # an ident tuple, make an ident
+            page_ident = skiboot.make_ident(value)
+            requested_page = skiboot.get_item(page_ident)
             if requested_page is None:
                 self[0] = "Unknown page"
             else:
@@ -136,13 +204,13 @@ class PageDescription(Widget):
     # This class does not display any error messages
     display_errors = False
 
-    arg_descriptions = {'page_ident':FieldArg("ident", ''),
+    arg_descriptions = {'page_ident':FieldArg("text", ''),
                         'span_text':FieldArg("text", "", jsonset=True)
                        }
 
     def __init__(self, name=None, brief='', **field_args):
         """
-        page_ident: The ident of a page or folder
+        page_ident: The label or ident of a page or folder
         span_text: if given, overrides the page description value
         """
         Widget.__init__(self, name=name, brief=brief, **field_args)
@@ -153,7 +221,59 @@ class PageDescription(Widget):
         if self.wf.span_text:
             self[0] = self.wf.span_text
         elif self.wf.page_ident:
-            requested_page = skiboot.get_item(self.wf.page_ident)
+            proj = skiboot.getproject(self.proj_ident)
+            if "/" in self.wf.page_ident:
+                # its a URL
+                self[0] = f"Unable to resolve {self.wf.page_ident}"
+                return
+
+            if self.wf.page_ident.isdigit():
+                # Its "integer"
+                try:
+                    value = (self.proj_ident, int(self.wf.page_ident))
+                except:
+                    self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                    return
+            elif ',' in self.wf.page_ident:
+                # Its a string such as "proj_ident,number"
+                vallist = self.wf.page_ident.split(',')
+                if len(vallist) != 2:
+                    self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                    return
+                lblproj = vallist[0].strip(" ()[]\"\'")
+                lblval = vallist[1].strip(" ()[]\"\'")
+                if lblval.isdigit():
+                    # Its "subproject, integer"
+                    try:
+                        value = (lblproj, int(lblval))
+                    except:
+                        self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                        return
+                else:
+                    # Its "subproject, label"
+                    subproj = skiboot.getproject(lblproj)
+                    if subproj is None:
+                        self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                        return
+                    value = subproj.resolve_label(lblval)
+            else:
+                 # its a label string of this project
+                if proj is None:
+                    self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                    return
+                value = proj.resolve_label(self.wf.page_ident)
+
+            # so value is one of the tuple ident, None, or URL
+            if not value:
+                self[0] = f"Unable to resolve the ident of {self.wf.page_ident}"
+                return
+            if isinstance(value, str):
+                # a url
+                self[0] = f"Given label points to URL rather than an ident"
+                return
+            # an ident tuple, make an ident
+            page_ident = skiboot.make_ident(value)
+            requested_page = skiboot.get_item(page_ident)
             if requested_page is None:
                 self[0] = "Unknown page"
             else:
@@ -195,7 +315,7 @@ class ProjectName(Widget):
         """Returns a text string to illustrate the widget"""
         return """
 <span>  <!-- with widget id and class widget_class -->
-  <!-- the project name -->
+  <!-- the project ident (usually the project name unless set otherwise) -->
 </span>
 """
 
@@ -262,7 +382,10 @@ class Redirector(Widget):
     """A widget containing javascript which redirects the page to the url
        Once the page is loaded, the redirection occurs, so normally
        this is the only widget on the page
-       A textblock is displayed with the link to the url if the client has javascript disabled"""
+       A textblock is displayed with the link to the url if the client has javascript disabled
+
+       If an error is raised with this widget as target, the error message should be a URL which the widget will
+       then use - causing a redirection on error."""
 
     arg_descriptions = {'url':FieldArg("text", ''),
                         'textblock_ref':FieldArg("textblock_ref", ""),
@@ -273,7 +396,7 @@ class Redirector(Widget):
 
     def __init__(self, name=None, brief='', **field_args):
         """
-        url: the url to redirect to
+        url: the url to redirect to, either a URL containing / character or a label
         textblock_ref: The reference of the TextBlock appearing in the paragraph
         text_refnotfound: text to appear if the textblock is not found
         text_replaceblock: text set here will replace the textblock
@@ -288,6 +411,7 @@ class Redirector(Widget):
 
     def _error_build(self, message):
         """Called if an error is raised"""
+        # sets the error message as the widget URL
         if message:
             self._url = message
 
@@ -299,7 +423,23 @@ class Redirector(Widget):
         else:
             url = self.wf.url
 
-        self[0][0] = "window.location.replace(\"%s\");" % (url,)
+        if not url:
+            self[1][0] = "Invalid URL given"
+            return
+
+        if "/" not in url:
+            # not a valid url, could be a label
+            proj = skiboot.getproject(self.proj_ident)
+            if proj is None:
+                self[1][0] = "Unable to resolve the URL"
+                return
+            value = proj.label_to_url(url)
+            if value is None:
+                self[1][0] = f"Invalid URL \"{url}\" has been given"
+                return
+            url = value
+        
+        self[0][0] = f"window.location.replace(\"{url}\");"
 
         linebreaks = bool(self.wf.linebreaks)
 
@@ -401,6 +541,46 @@ class ProgressBar1(Widget):
 
 
 
+class ProgressBar2(Widget):
+    """A div containing a progress bar, uses width of a div rather than the progress tag"""
+
+    # This class does not display any error messages
+    display_errors = False
+
+    arg_descriptions = {'value':FieldArg("integer", "0", jsonset=True),
+                        'bar_class':FieldArg("cssclass", '')
+                       }
+
+    def __init__(self, name=None, brief='', **field_args):
+        """
+        value is an integer representing a percentage between 0 and 100
+        bar_class should set the bar colour, such as w3-green
+        """
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "div"
+        self[0] = tag.Part(tag_name="div")
 
 
+    def _build(self, page, ident_list, environ, call_data, lang):
+        "build the widget"
+        if self.wf.value<0:
+            value = 0
+        elif self.wf.value>100:
+            value = 100
+        else:
+            value = self.wf.value
+        barstyle = f"height:24px;width:{value}%"
+        self[0].set_class_style(self.wf.bar_class, barstyle)
+
+
+    @classmethod
+    def description(cls):
+        """Returns a text string to illustrate the widget"""
+        return """
+<div>  <!-- with widget id and class widget_class -->
+ <div> <!-- with class bar_class and style width set to value -->
+ </div>
+</div>
+"""
+
 
