@@ -21,21 +21,22 @@ class SVGContainer(Widget):
 
     def __init__(self, name=None, brief='', **field_args):
         """Acts as an SVG widget, containing other widgets, so show, class and dimensions can be set"""
-        Widget.__init__(self, name=name, tag_name="svg", brief=brief, **field_args)
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "svg"
         self.htmlescaped = False
         self.linebreaks = False
         # the widget is a container
         self[0] = ""
 
     def _build(self, page, ident_list, environ, call_data, lang):
-        if self.get_field_value("width"):
-            self.update_attribs({"width":self.get_field_value("width")})
-        if self.get_field_value("height"):
-            self.update_attribs({"height":self.get_field_value("height")})
-        if self.get_field_value("viewBox"):
-            self.update_attribs({"viewBox":self.get_field_value("viewBox")})
-        if self.get_field_value("preserveAspectRatio"):
-            self.update_attribs({"preserveAspectRatio":self.get_field_value("preserveAspectRatio")})
+        if self.wf.width:
+            self.attribs["width"] = self.wf.width
+        if self.wf.height:
+            self.attribs["height"] = self.wf.height
+        if self.wf.viewBox:
+            self.attribs["viewBox"] = self.wf.viewBox
+        if self.wf.preserveAspectRatio:
+            self.attribs["preserveAspectRatio"] = self.wf.preserveAspectRatio
 
     @classmethod
     def description(cls):
@@ -59,15 +60,16 @@ class Group(Widget):
 
     def __init__(self, name=None, brief='', **field_args):
         """Acts as an g widget, containing other widgets, so group class, style, transform can be set"""
-        Widget.__init__(self, name=name, tag_name="g", brief=brief, **field_args)
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "g"
         self.htmlescaped = False
         self.linebreaks = False
         # The widget is a container
         self[0] = ""
 
     def _build(self, page, ident_list, environ, call_data, lang):
-        if self.get_field_value("transform"):
-            self.update_attribs({"transform":self.get_field_value("transform")})
+        if self.wf.transform:
+            self.attribs["transform"] = self.wf.transform
 
     @classmethod
     def description(cls):
@@ -101,25 +103,26 @@ class TextBlockGroup(Widget):
         content_replaceblock: content set here will replace the textblock
         """
         # pass fields to Widget
-        Widget.__init__(self, name=name, tag_name="g", brief=brief, **field_args)
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "g"
         self[0] = ''
         self.htmlescaped = False
         self.linebreaks = False
 
     def _build(self, page, ident_list, environ, call_data, lang):
         # define the textblock
-        tblock = self.get_field_value("textblock_ref")
-        tblock.project = self.get_field_value('textblock_project')
-        tblock.failmessage = self.get_field_value('content_refnotfound')
+        tblock = self.wf.textblock_ref
+        tblock.project = self.wf.textblock_project
+        tblock.failmessage = self.wf.content_refnotfound
         tblock.escape = False
         tblock.linebreaks = False
         # place it at location 0
-        if self.get_field_value("content_replaceblock"):
-            self[0] = self.get_field_value("content_replaceblock")
+        if self.wf.content_replaceblock:
+            self[0] = self.wf.content_replaceblock
         else:
             self[0] = tblock
-        if self.get_field_value("transform"):
-            self.update_attribs({"transform":self.get_field_value("transform")})
+        if self.wf.transform:
+            self.attribs["transform"] = self.wf.transform
 
     @classmethod
     def description(cls):
@@ -149,16 +152,17 @@ class TextGroup(Widget):
        text: the string set here will be set as content
         """
         # pass fields to Widget
-        Widget.__init__(self, name=name, tag_name="g", brief=brief, **field_args)
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "g"
         self[0] = ''
         self.htmlescaped = False
         self.linebreaks = False
 
     def _build(self, page, ident_list, environ, call_data, lang):
-        if self.get_field_value("text"):
-            self[0] = self.get_field_value("text")
-        if self.get_field_value("transform"):
-            self.update_attribs({"transform":self.get_field_value("transform")})
+        if self.wf.text:
+            self[0] = self.wf.text
+        if self.wf.transform:
+            self.attribs["transform"] = self.wf.transform
 
     @classmethod
     def description(cls):
@@ -201,7 +205,8 @@ class Rect(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="rect", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "rect"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
@@ -209,11 +214,11 @@ class Rect(ClosedWidget):
         # Note - all arg_descriptions are attributes, apart from stroke_width which is actually
         # attribute stroke-width. So update the tag with each item from arg_descriptions
         for att in self.arg_descriptions.keys():
-            if self.get_field_value(att):
+            if getattr(self.wf, att, ''):
                 if att == "stroke_width":
-                    self.update_attribs({"stroke-width":self.get_field_value(att)})
+                    self.attribs["stroke-width"] = getattr(self.wf, att)
                 else:
-                    self.update_attribs({att:self.get_field_value(att)})   
+                    self.attribs[att] = getattr(self.wf, att)
 
     @classmethod
     def description(cls):
@@ -256,31 +261,32 @@ class SimpleText(Widget):
         text: The text to display
         """
         # pass fields to Widget
-        Widget.__init__(self, name=name, tag_name="text", brief=brief, **field_args)
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "text"
         self.hide_if_empty=False
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
         "Set the attributes"
-        if self.get_field_value("x"):
-            self.update_attribs({"x":self.get_field_value("x")})
-        if self.get_field_value("y"):
-            self.update_attribs({"y":self.get_field_value("y")})
-        if self.get_field_value("dx"):
-            self.update_attribs({"dx":self.get_field_value("dx")})
-        if self.get_field_value("dy"):
-            self.update_attribs({"dy":self.get_field_value("dy")})
-        if self.get_field_value("font_family"):
-            self.update_attribs({"font-family":self.get_field_value("font_family")})
-        if self.get_field_value("font_size"):
-            self.update_attribs({"font-size":self.get_field_value("font_size")})
-        if self.get_field_value("fill"):
-            self.update_attribs({"fill":self.get_field_value("fill")})
-        if self.get_field_value("stroke"):
-            self.update_attribs({"stroke":self.get_field_value("stroke")})
-        if self.get_field_value("stroke_width"):
-            self.update_attribs({"stroke-width":self.get_field_value("stroke_width")})
-        self[0] = self.get_field_value("text")
+        if self.wf.x:
+            self.attribs["x"] = self.wf.x
+        if self.wf.y:
+            self.attribs["y"] = self.wf.y
+        if self.wf.dx:
+            self.attribs["dx"] = self.wf.dx
+        if self.wf.dy:
+            self.attribs["dy"] = self.wf.dy
+        if self.wf.font_family:
+            self.attribs["font-family"] = self.wf.font_family
+        if self.wf.font_size:
+            self.attribs["font-size"] = self.wf.font_size
+        if self.wf.fill:
+            self.attribs["fill"] = self.wf.fill
+        if self.wf.stroke:
+            self.attribs["stroke"] = self.wf.stroke
+        if self.wf.stroke_width:
+            self.attribs["stroke-width"] = self.wf.stroke_width
+        self[0] = self.wf.text
 
 
     @classmethod
@@ -318,33 +324,34 @@ class TextList(Widget):
         lines: List of lists, of [x,y,text]
         """
         # pass fields to Widget
-        Widget.__init__(self, name=name, tag_name="text", brief=brief, **field_args)
+        Widget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "text"
         self.hide_if_empty=False
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
         "Set the attributes"
-        if self.get_field_value("font_family"):
-            self.update_attribs({"font-family":self.get_field_value("font_family")})
-        if self.get_field_value("font_size"):
-            self.update_attribs({"font-size":self.get_field_value("font_size")})
-        if self.get_field_value("fill"):
-            self.update_attribs({"fill":self.get_field_value("fill")})
-        if self.get_field_value("stroke"):
-            self.update_attribs({"stroke":self.get_field_value("stroke")})
-        if self.get_field_value("stroke_width"):
-            self.update_attribs({"stroke-width":self.get_field_value("stroke_width")})
-        lines = self.get_field_value("lines")
+        if self.wf.font_family:
+            self.attribs["font-family"] = self.wf.font_family
+        if self.wf.font_size:
+            self.attribs["font-size"] = self.wf.font_size
+        if self.wf.fill:
+            self.attribs["fill"] = self.wf.fill
+        if self.wf.stroke:
+            self.attribs["stroke"] = self.wf.stroke
+        if self.wf.stroke_width:
+            self.attribs["stroke-width"] = self.wf.stroke_width
+        lines = self.wf.lines
         if not lines:
             return
         line1 = lines[0]
-        self.update_attribs({"x":str(line1[0])})
-        self.update_attribs({"y":str(line1[1])})
+        self.attribs["x"] = str(line1[0])
+        self.attribs["y"] = str(line1[1])
         self[0] = line1[2]
         for line in lines[1:]:
             tspan = tag.Part(tag_name='tspan', text = line[2])
-            tspan.update_attribs({"x":str(line[0])})
-            tspan.update_attribs({"y":str(line[1])})
+            tspan.attribs["x"] = str(line[0])
+            tspan.attribs["y"] = str(line[1])
             self.append(tspan)
 
     @classmethod
@@ -383,7 +390,8 @@ class Circle(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="circle", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "circle"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
@@ -391,11 +399,11 @@ class Circle(ClosedWidget):
         # Note - all arg_descriptions are attributes, apart from stroke_width which is actually
         # attribute stroke-width. So update the tag with each item from arg_descriptions
         for att in self.arg_descriptions.keys():
-            if self.get_field_value(att):
+            if getattr(self.wf, att, ''):
                 if att == "stroke_width":
-                    self.update_attribs({"stroke-width":self.get_field_value(att)})
+                    self.attribs["stroke-width"] = getattr(self.wf, att)
                 else:
-                    self.update_attribs({att:self.get_field_value(att)})   
+                    self.attribs[att] = getattr(self.wf, att)
 
     @classmethod
     def description(cls):
@@ -427,7 +435,8 @@ class Line(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="line", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "line"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
@@ -435,11 +444,12 @@ class Line(ClosedWidget):
         # Note - all arg_descriptions are attributes, apart from stroke_width which is actually
         # attribute stroke-width. So update the tag with each item from arg_descriptions
         for att in self.arg_descriptions.keys():
-            if self.get_field_value(att):
+            if getattr(self.wf, att, ''):
                 if att == "stroke_width":
-                    self.update_attribs({"stroke-width":self.get_field_value(att)})
+                    self.attribs["stroke-width"] = getattr(self.wf, att)
                 else:
-                    self.update_attribs({att:self.get_field_value(att)})   
+                    self.attribs[att] = getattr(self.wf, att)
+
 
     @classmethod
     def description(cls):
@@ -475,7 +485,8 @@ class Ellipse(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="ellipse", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "ellipse"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
@@ -483,11 +494,12 @@ class Ellipse(ClosedWidget):
         # Note - all arg_descriptions are attributes, apart from stroke_width which is actually
         # attribute stroke-width. So update the tag with each item from arg_descriptions
         for att in self.arg_descriptions.keys():
-            if self.get_field_value(att):
+            if getattr(self.wf, att, ''):
                 if att == "stroke_width":
-                    self.update_attribs({"stroke-width":self.get_field_value(att)})
+                    self.attribs["stroke-width"] = getattr(self.wf, att)
                 else:
-                    self.update_attribs({att:self.get_field_value(att)})
+                    self.attribs[att] = getattr(self.wf, att)
+
 
     @classmethod
     def description(cls):
@@ -519,27 +531,28 @@ class Polygon(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="polygon", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "polygon"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
         "Set the attributes"
 
-        if self.get_field_value("fill"):
-            self.update_attribs({"fill":self.get_field_value("fill")})
-        if self.get_field_value("stroke"):
-            self.update_attribs({"stroke":self.get_field_value("stroke")})
-        if self.get_field_value("stroke_width"):
-            self.update_attribs({"stroke-width":self.get_field_value("stroke_width")})
+        if self.wf.fill:
+            self.attribs["fill"] = self.wf.fill
+        if self.wf.stroke:
+            self.attribs["stroke"] = self.wf.stroke
+        if self.wf.stroke_width:
+            self.attribs["stroke-width"] = self.wf.stroke_width
 
-        if not self.get_field_value('points'):
+        if not self.wf.points:
             return
 
         points_att = ""
-        points = self.get_field_value('points')
+        points = self.wf.points
         for x,y in points:
             points_att += "%s,%s " % (x,y)
-        self.update_attribs({'points':points_att})   
+        self.attribs['points'] = points_att   
   
 
     @classmethod
@@ -572,27 +585,28 @@ class Polyline(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="polyline", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "polyline"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
         "Set the attributes"
 
-        if self.get_field_value("fill"):
-            self.update_attribs({"fill":self.get_field_value("fill")})
-        if self.get_field_value("stroke"):
-            self.update_attribs({"stroke":self.get_field_value("stroke")})
-        if self.get_field_value("stroke_width"):
-            self.update_attribs({"stroke-width":self.get_field_value("stroke_width")})
+        if self.wf.fill:
+            self.attribs["fill"] = self.wf.fill
+        if self.wf.stroke:
+            self.attribs["stroke"] = self.wf.stroke
+        if self.wf.stroke_width:
+            self.attribs["stroke-width"] = self.wf.stroke_width
 
-        if not self.get_field_value('points'):
+        if not self.wf.points:
             return
 
         points_att = ""
-        points = self.get_field_value('points')
+        points = self.wf.points
         for x,y in points:
             points_att += "%s,%s " % (x,y)
-        self.update_attribs({'points':points_att})   
+        self.attribs['points'] = points_att   
   
 
     @classmethod
@@ -624,7 +638,8 @@ class Path(ClosedWidget):
         stroke_width: The outline edge width
         """
         # pass fields to Widget
-        ClosedWidget.__init__(self, name=name, tag_name="path", brief=brief, **field_args)
+        ClosedWidget.__init__(self, name=name, brief=brief, **field_args)
+        self.tag_name = "path"
 
 
     def _build(self, page, ident_list, environ, call_data, lang):
@@ -632,11 +647,11 @@ class Path(ClosedWidget):
         # Note - all arg_descriptions are attributes, apart from stroke_width which is actually
         # attribute stroke-width. So update the tag with each item from arg_descriptions
         for att in self.arg_descriptions.keys():
-            if self.get_field_value(att):
+            if getattr(self.wf, att, ''):
                 if att == "stroke_width":
-                    self.update_attribs({"stroke-width":self.get_field_value(att)})
+                    self.attribs["stroke-width"] = getattr(self.wf, att)
                 else:
-                    self.update_attribs({att:self.get_field_value(att)})
+                    self.attribs[att] = getattr(self.wf, att)
 
     @classmethod
     def description(cls):
