@@ -270,24 +270,52 @@ SKIPOLE.setfields = function(result) {
         for (const widg_ident in widg_fields) {
             let fieldlist = widg_fields[widg_ident];
             let thiswidget = SKIPOLE.widgets[widg_ident]
+            // If given, update the widget_class and widget_style in fieldvalues, so they are available
+            // to thiswidget.setvalues even if they have been changed by JSON call 
             let widget_class = thiswidget.fieldarg_in_result('widget_class', result, fieldlist);
             if (widget_class != undefined) {
                 if (widget_class) {
                     $("#"+widg_ident).attr("class", widget_class);
+                    thiswidget.fieldvalues["widget_class"] = widget_class;
                     }
                 else {
                     $("#"+widg_ident).removeAttr("class");
+                    thiswidget.fieldvalues["widget_class"] = '';
                     }
                 }
             let widget_style = thiswidget.fieldarg_in_result('widget_style', result, fieldlist);
             if (widget_style != undefined) {
                 if (widget_style) {
                     $("#"+widg_ident).attr("style", widget_style);
+                    thiswidget.fieldvalues["widget_style"] = widget_style;
                     }
                 else {
                     $("#"+widg_ident).removeAttr("style");
+                    thiswidget.fieldvalues["widget_style"] = '';
                     }
                 }
+
+            // If set_highlight and highlight_class then check if widget
+            // class needs to be set
+            let highlight_class = thiswidget.fieldvalues["highlight_class"];
+            if (highlight_class != undefined) {
+                let set_highlight = thiswidget.fieldarg_in_result('set_highlight', result, fieldlist);
+                if (set_highlight != undefined){
+                    if (set_highlight) {
+                        $("#"+widg_ident).attr("class", highlight_class);
+                        }
+                    else {
+                        let stored_widget_class = thiswidget.fieldvalues["widget_class"];
+                        if (stored_widget_class){
+                            $("#"+widg_ident).attr("class", stored_widget_class);
+                            }
+                        else {
+                            $("#"+widg_ident).removeAttr("class");
+                            }
+                        }
+                     }
+                }
+
             // now call widget method to set any other values
             thiswidget.setvalues(fieldlist, result);
             }
